@@ -13,7 +13,7 @@
 # This is free software: you may copy, modify, and/or distribute this work
 # under the terms of the Apache License, version 2.0 as published by the
 # Apache Software Foundation.
-# No warranty expressed or implied. See the file ‘LICENSE.ASF-2’ for details.
+# No warranty expressed or implied. See the file LICENSE.ASF-2 for details.
 
 """ Daemon process behaviour.
     """
@@ -33,7 +33,7 @@ try:
     # Base type of strings in Python 2.
     basestring
 except NameError:
-    # Python 3 promotes Unicode to the primary string type.
+    # Python 3 only has one string type.
     basestring = str
 
 
@@ -108,15 +108,9 @@ class DaemonContext(object):
             File access creation mask (“umask”) to set for the process on
             daemon start.
 
-            A daemon should not rely on the parent process's umask value,
-            which is beyond its control and may prevent creating a file with
-            the required access mode. So when the daemon context opens, the
-            umask is set to an explicit known value.
-
-            If the conventional value of 0 is too open, consider setting a
-            value such as 022, 027, 077, or another specific value.
-            Otherwise, ensure the daemon creates every file with an
-            explicit access mode for the purpose.
+            Since a process inherits its umask from its parent process,
+            starting the daemon will reset the umask to this value so that
+            files are created by the daemon with access modes as it expects.
 
         `pidfile`
             :Default: ``None``
@@ -484,7 +478,7 @@ def change_working_directory(directory):
         """
     try:
         os.chdir(directory)
-    except Exception, exc:
+    except Exception as exc:
         error = DaemonOSEnvironmentError(
                 "Unable to change working directory (%(exc)s)"
                     % vars())
@@ -502,7 +496,7 @@ def change_root_directory(directory):
     try:
         os.chdir(directory)
         os.chroot(directory)
-    except Exception, exc:
+    except Exception as exc:
         error = DaemonOSEnvironmentError(
                 "Unable to change root directory (%(exc)s)"
                     % vars())
@@ -514,7 +508,7 @@ def change_file_creation_mask(mask):
         """
     try:
         os.umask(mask)
-    except Exception, exc:
+    except Exception as exc:
         error = DaemonOSEnvironmentError(
                 "Unable to change file creation mask (%(exc)s)"
                     % vars())
@@ -532,7 +526,7 @@ def change_process_owner(uid, gid):
     try:
         os.setgid(gid)
         os.setuid(uid)
-    except Exception, exc:
+    except Exception as exc:
         error = DaemonOSEnvironmentError(
                 "Unable to change process owner (%(exc)s)"
                     % vars())
@@ -553,7 +547,7 @@ def prevent_core_dump():
         # Ensure the resource limit exists on this platform, by requesting
         # its current value.
         core_limit_prev = resource.getrlimit(core_resource)
-    except ValueError, exc:
+    except ValueError as exc:
         error = DaemonOSEnvironmentError(
                 "System does not support RLIMIT_CORE resource limit (%(exc)s)"
                     % vars())
@@ -573,7 +567,7 @@ def detach_process_context():
         Reference: “Advanced Programming in the Unix Environment”,
         section 13.3, by W. Richard Stevens, published 1993 by
         Addison-Wesley.
-
+    
         """
 
     def fork_then_exit_parent(error_message):
@@ -587,7 +581,7 @@ def detach_process_context():
             pid = os.fork()
             if pid > 0:
                 os._exit(0)
-        except OSError, exc:
+        except OSError as exc:
             exc_errno = exc.errno
             exc_strerror = exc.strerror
             error = DaemonProcessDetachError(
@@ -605,7 +599,7 @@ def is_process_started_by_init():
 
         The `init` process has the process ID of 1; if that is our
         parent process ID, return ``True``, otherwise ``False``.
-
+    
         """
     result = False
 
@@ -630,7 +624,7 @@ def is_socket(fd):
     try:
         socket_type = file_socket.getsockopt(
                 socket.SOL_SOCKET, socket.SO_TYPE)
-    except socket.error, exc:
+    except socket.error as exc:
         exc_errno = exc.args[0]
         if exc_errno == errno.ENOTSOCK:
             # Socket operation on non-socket.
@@ -652,7 +646,7 @@ def is_process_started_by_superserver():
         attaches it to the standard streams of the child process. If
         that is the case for this process, return ``True``, otherwise
         ``False``.
-
+    
         """
     result = False
 
@@ -690,7 +684,7 @@ def close_file_descriptor_if_open(fd):
         """
     try:
         os.close(fd)
-    except OSError, exc:
+    except OSError as exc:
         if exc.errno == errno.EBADF:
             # File descriptor was not open.
             pass
