@@ -12,7 +12,7 @@
 # This is free software: you may copy, modify, and/or distribute this work
 # under the terms of the Apache License, version 2.0 as published by the
 # Apache Software Foundation.
-# No warranty expressed or implied. See the file ‘LICENSE.ASF-2’ for details.
+# No warranty expressed or implied. See the file LICENSE.ASF-2 for details.
 
 """ Daemon runner library.
     """
@@ -24,7 +24,9 @@ import os
 import signal
 import errno
 
-from . import pidlockfile
+import lockfile
+
+from . import pidfile
 from .daemon import DaemonContext
 
 
@@ -72,7 +74,7 @@ class DaemonRunner(object):
 
             * `run`: Callable that will be invoked when the daemon is
               started.
-
+            
             """
         self.parse_args()
         self.app = app
@@ -120,7 +122,7 @@ class DaemonRunner(object):
 
         try:
             self.daemon_context.open()
-        except pidlockfile.AlreadyLocked:
+        except lockfile.AlreadyLocked:
             pidfile_path = self.pidfile.path
             raise DaemonRunnerStartFailureError(
                     "PID file %(pidfile_path)r already locked" % vars())
@@ -137,7 +139,7 @@ class DaemonRunner(object):
         pid = self.pidfile.read_pid()
         try:
             os.kill(pid, signal.SIGTERM)
-        except OSError, exc:
+        except OSError as exc:
             raise DaemonRunnerStopFailureError(
                     "Failed to terminate %(pid)d: %(exc)s" % vars())
 
@@ -203,7 +205,7 @@ def make_pidlockfile(path, acquire_timeout):
     if not os.path.isabs(path):
         error = ValueError("Not an absolute path: %(path)r" % vars())
         raise error
-    lockfile = pidlockfile.TimeoutPIDLockFile(path, acquire_timeout)
+    lockfile = pidfile.TimeoutPIDLockFile(path, acquire_timeout)
 
     return lockfile
 
@@ -222,9 +224,9 @@ def is_pidfile_stale(pidfile):
     if pidfile_pid is not None:
         try:
             os.kill(pidfile_pid, signal.SIG_DFL)
-        except OSError, exc:
+        except OSError as exc:
             if exc.errno == errno.ESRCH:
-                # The specified PID does not exist.
+                # The specified PID does not exist
                 result = True
 
     return result
